diff -Naur a/alsa-kernel/pci/hda/patch_sigmatel.c b/alsa-kernel/pci/hda/patch_sigmatel.c
--- a/alsa-kernel/pci/hda/patch_sigmatel.c	2009-11-16 15:38:26.000000000 +0100
+++ b/alsa-kernel/pci/hda/patch_sigmatel.c	2009-11-16 19:19:01.110495159 +0100
@@ -1063,6 +1063,16 @@
 static void stac92xx_free_kctls(struct hda_codec *codec);
 static int stac92xx_add_jack(struct hda_codec *codec, hda_nid_t nid, int type);
 
+static void stac_add_mixer(struct sigmatel_spec *spec,
+              struct snd_kcontrol_new *knew)
+{
+   if (!knew)
+       return;
+   if (snd_BUG_ON(spec->num_mixers >= ARRAY_SIZE(spec->mixers)))
+       return;
+   spec->mixers[spec->num_mixers++] = knew;
+}
+
 static int stac92xx_build_controls(struct hda_codec *codec)
 {
 	struct sigmatel_spec *spec = codec->spec;
@@ -3825,8 +3835,7 @@
 	if (dig_in && spec->autocfg.dig_in_pin)
 		spec->dig_in_nid = dig_in;
 
-	if (spec->kctls.list)
-		spec->mixers[spec->num_mixers++] = spec->kctls.list;
+    stac_add_mixer(spec, spec->kctls.list);
 
 	spec->input_mux = &spec->private_imux;
 	if (!spec->dinput_mux)
@@ -3935,8 +3944,7 @@
 	if (spec->autocfg.dig_in_pin)
 		spec->dig_in_nid = 0x04;
 
-	if (spec->kctls.list)
-		spec->mixers[spec->num_mixers++] = spec->kctls.list;
+    stac_add_mixer(spec, spec->kctls.list);
 
 	spec->input_mux = &spec->private_imux;
 	spec->dinput_mux = &spec->private_dimux;
@@ -5280,6 +5288,54 @@
 		return 0;
 }
 
+/* HP dv7 bass volume - GPIO5 */
+#define stac_hp_bass_gpio_info snd_ctl_boolean_mono_info
+static int stac_hp_bass_gpio_get(struct snd_kcontrol *kcontrol,
+                struct snd_ctl_elem_value *ucontrol)
+{
+   struct hda_codec *codec = snd_kcontrol_chip(kcontrol);
+   struct sigmatel_spec *spec = codec->spec;
+   ucontrol->value.integer.value[0] = !!(spec->gpio_data & 0x20);
+   return 0;
+}
+
+static int stac_hp_bass_gpio_put(struct snd_kcontrol *kcontrol,
+                struct snd_ctl_elem_value *ucontrol)
+{
+   struct hda_codec *codec = snd_kcontrol_chip(kcontrol);
+   struct sigmatel_spec *spec = codec->spec;
+   unsigned int gpio_data;
+
+   gpio_data = (spec->gpio_data & ~0x20) |
+       (ucontrol->value.integer.value[0] ? 0x20 : 0);
+   if (gpio_data == spec->gpio_data)
+       return 0;
+   spec->gpio_data = gpio_data;
+   stac_gpio_set(codec, spec->gpio_mask, spec->gpio_dir, spec->gpio_data);
+   return 1;
+}
+
+static struct snd_kcontrol_new stac_hp_bass_volume_ctrl[] = {
+   {
+       .iface = SNDRV_CTL_ELEM_IFACE_MIXER,
+       .name = "Bass Speaker Playback Volume",
+       .info = stac_hp_bass_gpio_info,
+       .get = stac_hp_bass_gpio_get,
+       .put = stac_hp_bass_gpio_put,
+   },
+   {} /* terminator */
+};
+
+static void stac_add_hp_bass_volume(struct hda_codec *codec)
+{
+   struct sigmatel_spec *spec = codec->spec;
+
+   spec->gpio_mask |= 0x20;
+   spec->gpio_dir |= 0x20;
+   spec->gpio_data |= 0x20;
+   stac_add_mixer(spec, stac_hp_bass_volume_ctrl);
+}
+
 static int patch_stac92hd71bxx(struct hda_codec *codec)
 {
 	struct sigmatel_spec *spec;
@@ -5468,6 +5524,18 @@
 		break;
 	}
 
+       /* enable LFE on HP dv7 if available */
+       if (spec->board_config == STAC_HP_DV5) {
+               unsigned int cap;
+               cap = snd_hda_param_read(codec, 0x1, AC_PAR_GPIO_CAP);
+               cap &= AC_GPIO_IO_COUNT;
+               if (cap >= 6) {
+                       spec->gpio_mask |= 0x20;
+                       spec->gpio_dir |= 0x20;
+                       spec->gpio_data |= 0x20;
+               }
+       }
+
 	if (hp_bseries_system(codec->subsystem_id)) {
 		pin_cfg = snd_hda_codec_get_pincfg(codec, 0x0f);
 		if (get_defcfg_device(pin_cfg) == AC_JACK_LINE_OUT ||
@@ -5536,6 +5604,15 @@
 		return err;
 	}
 
+    /* enable LFE on HP dv7 if available */
+    if (spec->board_config == STAC_HP_DV5) {
+        unsigned int cap;
+        cap = snd_hda_param_read(codec, 0x1, AC_PAR_GPIO_CAP);
+        cap &= AC_GPIO_IO_COUNT;
+        if (cap >= 6)
+            stac_add_hp_bass_volume(codec);
+    }
+
 	codec->proc_widget_hook = stac92hd7x_proc_hook;
 
 	return 0;
